shouldBounceOnTap property
Whether the modal background should bounce when the dismiss barrier is tapped.
Implementation
final bool shouldBounceOnTap;
Whether the modal background should bounce when the dismiss barrier is tapped.
final bool shouldBounceOnTap;