SDropdownDecorations class
Utility class for creating common dropdown decorations
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
- material ↔ SDropdownDecoration
-
Material design style decoration
getter/setter pair
- outlined ↔ SDropdownDecoration
-
Outlined style decoration
getter/setter pair
- rounded ↔ SDropdownDecoration
-
Rounded style decoration
getter/setter pair