SContextMenuItem class
Constructors
- SContextMenuItem({required String label, IconData? icon, required VoidCallback onPressed, String? id, String? semanticsLabel, bool destructive = false, bool keepMenuOpen = false, bool disabled = false, String? shortcutHint})
Properties
- destructive → bool
-
final
- disabled → bool
-
Whether this item is disabled (grayed out, non-interactive).
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- icon → IconData?
-
final
- id → String?
-
final
- keepMenuOpen → bool
-
final
- label → String
-
final
- onPressed → VoidCallback
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- semanticsLabel → String?
-
final
- shortcutHint → String?
-
Optional keyboard shortcut hint displayed on the right side (e.g., "⌘C").
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override